summaryrefslogtreecommitdiff
path: root/plugins/plugin.h
diff options
context:
space:
mode:
authorElena Reshetova <elena.reshetova@intel.com>2012-11-22 20:49:27 +0200
committerAnas Nashif <anas.nashif@intel.com>2013-02-02 16:44:45 -0800
commit78b3ad646be7c502f0e9b7d1b76de76ba50601ca (patch)
treebaed6eccbcffabf34788215da13f264a57e73d48 /plugins/plugin.h
parentdca7f1cdfdcdee92e0c4e835e40472f59660d2b4 (diff)
downloadlibrpm-tizen-78b3ad646be7c502f0e9b7d1b76de76ba50601ca.tar.gz
librpm-tizen-78b3ad646be7c502f0e9b7d1b76de76ba50601ca.tar.bz2
librpm-tizen-78b3ad646be7c502f0e9b7d1b76de76ba50601ca.zip
Improving scriptlet related rpm plugin hooks.
Three new hooks added: PLUGINHOOK_SCRIPTLET_PRE_FUNC Called before scriptlet execution PLUGINHOOK_SCRIPTLET_FORK_POST_FUNC Called after fork() but before scriptlet execution PLUGINHOOK_SCRIPTLET_POST_FUNC Called after scriptlet execution Currently pre and post hooks are called for externals and internal lua scripts. post hook is called even if scriptlet execution has failed and the return code is given as an argument. fork_post hook is only called for external scriptlets, because for internal scriptlets no fork() is currently performed. Signed-off-by: Panu Matilainen <pmatilai@redhat.com>
Diffstat (limited to 'plugins/plugin.h')
-rw-r--r--plugins/plugin.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/plugins/plugin.h b/plugins/plugin.h
index cf49f8a97..dec3bfd23 100644
--- a/plugins/plugin.h
+++ b/plugins/plugin.h
@@ -25,5 +25,7 @@ rpmRC PLUGINHOOK_TSM_POST_FUNC(rpmts ts);
rpmRC PLUGINHOOK_PSM_PRE_FUNC(rpmte te);
rpmRC PLUGINHOOK_PSM_POST_FUNC(rpmte te);
-/*per script plugin hooks */
-rpmRC PLUGINHOOK_SCRIPT_SETUP_FUNC(char* path);
+/*per scriptlet plugin hooks */
+rpmRC PLUGINHOOK_SCRIPTLET_PRE_FUNC(const char *s_name, int type);
+rpmRC PLUGINHOOK_SCRIPTLET_FORK_POST_FUNC(const char *path, int type);
+rpmRC PLUGINHOOK_SCRIPTLET_POST_FUNC(const char *s_name, int type, int res);